aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/ItemInHandRenderer.h
diff options
context:
space:
mode:
authordaoge <3523206925@qq.com>2026-03-03 03:04:10 +0800
committerGitHub <noreply@github.com>2026-03-03 03:04:10 +0800
commitb3feddfef372618c8a9d7a0abcaf18cfad866c18 (patch)
tree267761c3bb39241ba5c347bfbe2254d06686e287 /Minecraft.Client/ItemInHandRenderer.h
parent84c31a2331f7a0ec85b9d438992e244f60e5020f (diff)
feat: TU19 (Dec 2014) Features & Content (#155)
* try to resolve merge conflict * feat: TU19 (Dec 2014) Features & Content (#32) * December 2014 files * Working release build * Fix compilation issues * Add sound to Windows64Media * Add DLC content and force Tutorial DLC * Revert "Add DLC content and force Tutorial DLC" This reverts commit 97a43994725008e35fceb984d5549df9c8cea470. * Disable broken light packing * Disable breakpoint during DLC texture map load Allows DLC loading but the DLC textures are still broken * Fix post build not working * ... * fix vs2022 build * fix cmake build --------- Co-authored-by: Loki <lokirautio@gmail.com>
Diffstat (limited to 'Minecraft.Client/ItemInHandRenderer.h')
-rw-r--r--Minecraft.Client/ItemInHandRenderer.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/Minecraft.Client/ItemInHandRenderer.h b/Minecraft.Client/ItemInHandRenderer.h
index dee51a7f..b5d840a2 100644
--- a/Minecraft.Client/ItemInHandRenderer.h
+++ b/Minecraft.Client/ItemInHandRenderer.h
@@ -3,19 +3,25 @@
class Minecraft;
class ItemInstance;
class Minimap;
-class Mob;
+class LivingEntity;
class TileRenderer;
class Tesselator;
class ItemInHandRenderer
{
+public:
+ // 4J - made these public
+ static ResourceLocation ENCHANT_GLINT_LOCATION;
+ static ResourceLocation MAP_BACKGROUND_LOCATION;
+ static ResourceLocation UNDERWATER_LOCATION;
+
private:
- Minecraft *mc;
+ Minecraft *minecraft;
shared_ptr<ItemInstance> selectedItem;
float height;
float oHeight;
TileRenderer *tileRenderer;
- static int list, listGlint;
+ static int listItem, listGlint, listTerrain;
public:
// 4J Stu - Made public so we can use it from ItemFramRenderer
@@ -23,8 +29,8 @@ public:
public:
ItemInHandRenderer(Minecraft *mc, bool optimisedMinimap = true); // 4J Added optimisedMinimap param
- void renderItem(shared_ptr<Mob> mob, shared_ptr<ItemInstance> item, int layer, bool setColor = true); // 4J added setColor parameter
- static void renderItem3D(Tesselator *t, float u0, float v0, float u1, float v1, int width, int height, float depth, bool isGlint); // 4J added isGlint parameter
+ void renderItem(shared_ptr<LivingEntity> mob, shared_ptr<ItemInstance> item, int layer, bool setColor = true); // 4J added setColor parameter
+ static void renderItem3D(Tesselator *t, float u0, float v0, float u1, float v1, int width, int height, float depth, bool isGlint, bool isTerrain); // 4J added isGlint and isTerrain parameter
public:
void render(float a);
void renderScreenEffect(float a);